Work order

Client: | Juca | Sale #: | 09183
Sales Person: | SalesPerson | Open Date: | 04/20/12
|  | Estimated finish: |

Code | Item | Quantity | Price | Total
Total: | $ 0.00

Method | Value
Missing | 0

Sales Person: | SalesPerson
Client: | Juca
Sale #: | 09183 | Work Order #: | 03384
Open Date: | 04/20/12 | Estimated Finish: |

Code | Item | Quantity

Sale: | 09183 | Date: | 04/20/12
|  | Deliver: |
Owner: | None

Longe | Esf | Cil | Eixo | DNP | Alt | Prima
OD: | 0.00 | 0.00 | 0.00 | 0.00 | 0.00 | 0.00
OE: | 0.00 | 0.00 | 0.00 | 0.00 | 0.00 | 0.00

Perto | Esf | Cil | Eixo | DNP | Adição
OD: | 0.00 | 0.00 | 0.00 | 0.00 | 0.00
OE: | 0.00 | 0.00 | 0.00 | 0.00 | 0.00